@@ -43,7 +43,13 @@
 #include <QTest>
 
 QTEST_MAIN(IncidenceFormatterTest)
-
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    setenv("LC_ALL", "en_US.utf-8", 1);
+}
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
 using namespace KCalCore;
 using namespace KCalUtils;
 
